@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: intrface.c 751 2004-06-17 10:04:25Z roms $ */
+/* $Id: intrface.c 853 2005-02-09 15:48:57Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -389,12 +389,18 @@ TICALL ticable_set_cable(int type, TicableLinkCable * lc)
   	// determine the best I/O method to use.
 	ret = mapping_get_method(type, resources, &method);
 	if(ret)
+	{
+		print_settings();
 		return ret;
+	}
 
   	// set the link cable
   	ret = mapping_register_cable(type, lc);
   	if(ret)
+	{
+		print_settings();
 		return ret;
+	}
 
   	// displays useful infos
   	print_settings();
