@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_par.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: par_link.c 370 2004-03-22 18:47:32Z roms $ */
 
-/*  libticables2 - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Lievin
+/*  libticables - Ti Link Cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,21 +25,18 @@
 #include <config.h>
 #endif
 
-#ifndef NO_CABLE_PAR
 
-#if defined(__LINUX__) && defined(HAVE_LINUX_PARPORT_H)
-#include "linux/link_par.c"
+#if defined(__LINUX__)
+#include "linux/par_link.c"
 
-#elif defined(__BSD__) && defined(HAVE_LINUX_PARPORT_H)
-#include "linux/link_par.c"
+#elif defined(__BSD__)
+#include "linux/par_link.c"
 
 #elif defined(__WIN32__)
-#include "win32/link_par.c"
+#include "linux/par_link.c"
 
 #elif defined(__MACOSX__)
 #include "none.c"
 
 #else
 #endif
-
-#endif
