@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_tie.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: tie_link.c 370 2004-03-22 18:47:32Z roms $ */
 
-/*  libticables2 - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Lievin
+/*  libticables - Ti Link Cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,21 +25,18 @@
 #include <config.h>
 #endif
 
-#ifndef NO_CABLE_TIE
 
 #if defined(__LINUX__)
-#include "linux/link_tie.c"
+#include "linux/tie_link.c"
 
 #elif defined(__BSD__)
-#include "linux/link_tie.c"
+#include "linux/tie_link.c"
 
 #elif defined(__WIN32__)
-#include "win32/link_tie.c"
+#include "win32/tie_link.c"
 
 #elif defined(__MACOSX__)
-#include "linux/link_tie.c"
+#include "none.c"
 
 #else
 #endif
-
-#endif
