@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: linux_ioports.c 721 2004-05-22 18:22:37Z roms $ */
+/* $Id: linux_ioports.c 899 2005-03-14 09:41:20Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -35,8 +35,12 @@
 #include <sys/ioctl.h>
 #include <fcntl.h>
 
-#if defined(__I386__) && defined(HAVE_ASM_IO_H) && defined(HAVE_SYS_PERM_H)
+#if defined(__I386__) && defined(HAVE_SYS_PERM_H)
 #include <sys/perm.h>
+#endif
+#if defined(__I386__) && defined(HAVE_SYS_IO_H)
+#include <sys/io.h>
+#elif defined(__I386__) && defined(HAVE_ASM_IO_H)
 #include <asm/io.h>
 #endif
 
