@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: type2str.c 651 2004-04-25 15:22:07Z roms $ */
+/* $Id: type2str.c 689 2004-05-09 20:29:44Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -22,7 +22,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "intl1.h"
+#include "gettext.h"
 #include "cabl_def.h"
 
 static const char *TICABLETYPE[TICABLETYPE_MAX] = {
@@ -104,11 +104,14 @@ TIEXPORT TicableHfc TICALL ticable_string_to_hfc(const char *str)
 }
 
 static const char *TICABLEPORT[TICABLEPORT_MAX] = {
-  N_("custom"), N_("parallel port #1"), N_("parallel port #2"), N_("parallel port #3"), 
-  N_("serial port #1"), N_("serial port #2"), N_("serial port #3"), N_("serial port #4"), 
+  N_("custom"), 
+  N_("parallel port #1"), N_("parallel port #2"), N_("parallel port #3"), 
+  N_("serial port #1"), N_("serial port #2"), 
+  N_("serial port #3"), N_("serial port #4"), 
   N_("virtual port #1"), N_("virtual port #2"), 
   N_("USB port #1"), N_("USB port #2"), N_("USB port #3"), N_("USB port #4"), 
-  N_("serial port"), N_("USB port")
+  N_("serial port"), N_("USB port"), 
+  N_("null"),
 };
 
 TIEXPORT const char *TICALL ticable_port_to_string(TicablePort port)
@@ -154,6 +157,8 @@ const char *TICALL ticable_method_to_string(TicableMethod method)
 		strcpy(buffer, _("kernel mode (module)"));
 	if (method & IOM_IOCTL)
 		strcpy(buffer, _("user mode (ioctl)"));
+	if (method & IOM_NULL)
+		strcpy(buffer, _("null"));
 
 	return buffer;
 }
