@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: verbose.c 651 2004-04-25 15:22:07Z roms $ */
+/* $Id: verbose.c 727 2004-05-24 17:40:21Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -38,10 +38,15 @@
 # include <windows.h>
 #endif
 
+#include "gettext.h"
 #include "export.h"
 #include "verbose.h"
 #include "printl.h"
 
+#ifdef __WIN32__
+#define vsnprintf _vsnprintf
+#endif
+
 // for compatibility
 TIEXPORT int TICALL DISPLAY(const char *format, ...)
 {
@@ -49,7 +54,9 @@ TIEXPORT int TICALL DISPLAY(const char *format, ...)
 	int ret;
 		
 	va_start(ap, format);
-    	ret = printl1(0, format, ap);
+	//ret = vsnprintf(buf, 256, format, ap);
+    	//ret = printl1(0, "%s", buf);
+	ret = vprintf(format, ap);
     	va_end(ap);
 	
 	return ret;
@@ -62,8 +69,11 @@ TIEXPORT int TICALL DISPLAY_ERROR(const char *format, ...)
 	int ret;
 		
 	va_start(ap, format);
-    	ret = printl1(2, format, ap);
-    	va_end(ap);
+	//ret = vsnprintf(buf, 256, format, ap);
+    	//ret = printl1(2, "%s", buf);
+    	printf(_("err: "));
+	ret = vprintf(format, ap);
+	va_end(ap);
 	
 	return ret;
 }
